Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(229)

Unified Diff: content/browser/service_worker/service_worker_registration.h

Issue 717353004: ServiceWorker: Add support for .skipWaiting and controllerchange event(2/3) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase again Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/service_worker/service_worker_registration.h
diff --git a/content/browser/service_worker/service_worker_registration.h b/content/browser/service_worker/service_worker_registration.h
index 3aee44bb51b302c60c83ce7bb0b0b62ce27bd18d..6a8d11fcac988e4ed81c51d19563e83879575f50 100644
--- a/content/browser/service_worker/service_worker_registration.h
+++ b/content/browser/service_worker/service_worker_registration.h
@@ -46,6 +46,7 @@ class CONTENT_EXPORT ServiceWorkerRegistration
ServiceWorkerRegistration* registration) {}
virtual void OnUpdateFound(
ServiceWorkerRegistration* registration) {}
+ virtual void OnSkippedWaiting(ServiceWorkerRegistration* registation) {}
};
ServiceWorkerRegistration(const GURL& pattern,
@@ -104,7 +105,8 @@ class CONTENT_EXPORT ServiceWorkerRegistration
// Triggers the [[Activate]] algorithm when the currently active version
// has no controllees. If there are no controllees at the time the method
// is called, activation is initiated immediately.
void ActivateWaitingVersionWhenReady();
// Triggers the [[ClearRegistration]] algorithm when the currently
@@ -104,7 +105,8 @@ class CONTENT_EXPORT ServiceWorkerRegistration
// Triggers the [[Activate]] algorithm when the currently active version
// has no controllees. If there are no controllees at the time the method
- // is called, activation is initiated immediately.
+ // is called or when version's skip waiting flag is set, activation is
+ // initiated immediately.
void ActivateWaitingVersionWhenReady();
// Triggers the [[ClearRegistration]] algorithm when the currently

Powered by Google App Engine
This is Rietveld 408576698